<?php

namespace Drupal\ginvite\Plugin\Group\RelationHandler;

use Drupal\group\Plugin\Group\RelationHandler\PermissionProviderInterface;
use Drupal\group\Plugin\Group\RelationHandler\PermissionProviderTrait;

/**
 * Provides group permissions for the group_invitation relation plugin.
 */
class GroupInvitationPermissionProvider implements PermissionProviderInterface {

  use PermissionProviderTrait;

  /**
   * Constructs a new GroupMembershipPermissionProvider.
   *
   * @param \Drupal\group\Plugin\Group\RelationHandler\PermissionProviderInterface $parent
   *   The default permission provider.
   */
  public function __construct(PermissionProviderInterface $parent) {
    $this->parent = $parent;
  }

  /**
   * {@inheritdoc}
   */
  public function getPermission($operation, $target, $scope = 'any') {
    if ($operation === 'delete' && $target === 'relation' && $scope === 'any') {
      return "$operation $scope invitations";
    }
    if ($operation === 'create' && $target === 'relation') {
      return 'invite users to group';
    }
    if ($operation === 'view' && $target === 'relation') {
      return 'view group invitations';
    }
    return $this->parent->getPermission($operation, $target, $scope);
  }

  /**
   * {@inheritdoc}
   */
  public function buildPermissions() {
    $permissions = $this->parent->buildPermissions();

    $permissions['invite users to group'] = [
      'title' => 'Invite users to group',
      'description' => 'Allows users with permissions to invite new users to group.',
    ];
    $permissions['view group invitations'] = [
      'title' => 'View group invitations',
      'description' => 'Allows users with permissions view created invitations.',
    ];
    $permissions['delete own invitations'] = [
      'title' => 'Delete own invitations',
      'description' => 'Allows users with permissions to delete own invitations to group.',
    ];
    $permissions['delete any invitation'] = [
      'title' => 'Delete any invitation',
      'description' => 'Allows users with permissions to delete any invitation to group.',
    ];

    return $permissions;
  }

}
